/**
 * qzmoo 是轻知商务整理的一套最基础的实用函数集
 * @author qzmoo.cn
 * @version 1.0.0
 */

var qzmoo = {
	s: null,
	shares: null,
	config: {
		host: 'http://www.qzmoo.com',
		page: 1,
		pagesize: 10,
	},
	
	touchClick: function(obj, fun) {
		/**
		* 该方法用于绑定点击事件，比一般的click事件反应速度快2倍。
		* @author qzmoo.cn
		* @param obj 要绑定的dom对象
		* @param fun 事件触发的函数
		*/
		var start_x = 0,
			start_y = 0;
		obj.addEventListener('touchstart',function(e){
			start_x = e.touches[0].clientX;
			start_y = e.touches[0].clientY;
			document.addEventListener('touchend', touEnd, false);
		});
		function touEnd(e){
			var endX = e.changedTouches[0].clientX;
			var endY = e.changedTouches[0].clientY;
			if(Math.abs(endX - start_x) < 5 && Math.abs(endY - start_y) < 5) {
				fun.call(obj,e);
			}
			document.removeEventListener('touchend', touEnd, false);
		};
	},
	
	isEmail: function(str) {
		/**
		* 该方法用于检测邮箱格式。
		* @author qzmoo.cn
		* @param str 要检查的邮箱字符串
		*/
		var reg = /^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])+/;
		return reg.test(str);
	},
	
	isPhone: function(str) {
		/**
		* 该方法用于检测手机号码格式。
		* @author qzmoo.cn
		* @param str 要检查的手机号字符串
		*/
		var reg = /(^0{0,1}1[3|4|5|6|7|8|9][0-9]{9}$)/; 
		if (!reg.exec(str)) { 
			return false; 
		}else{
			return true; 
		}
	},
	
	getParam: function(a) {
		/**
		* 该方法用于获取地址栏后的get参数。
		* @author qzmoo.cn
		* @param a 参数名称
		*/
		var reg = new RegExp("(^|&)" + a + "=([^&]*)(&|$)", "i");
		var r = window.location.search.substr(1).match(reg);
		if (r != null) return unescape(r[2]); return null;
	},
	
	ckeNum: function(a){
		var _this = a
		_this.value=_this.value.replace(/[^\d\.]/g,'')
	},
	
	clearin: function(a) {
		var _this = a
		_this.value = ''
	},
	
	addPath: function(a, b) {
		/**
		* 该方法用于增加前缀地址。
		* @author qzmoo.cn
		* @param a 增加的字符串
		* @param b 需要增加前缀的字符串
		*/
		var http_url = a || "http://www.qzmoo.cn";
		var tem = b;
		
		if(b){
			if(tem.toLowerCase().indexOf("http://") != -1){
				return b;
			}else{
				b = "/" + b;
				b = b.replace("//","/");
				return http_url + b;
			}
		}else{
			return http_url;
		}
	},
	
	getAge: function(a) {
		/**
		* 该方法用于根据年份计算年龄。
		* @author qzmoo.cn
		* @param str 年份
		*/
		if(!a){
			return(0);  
		}
		var reg = a.match(/^(\d{1,4})(-|\/)(\d{1,2})\2(\d{1,2})$/);
		if(reg==null)return false;    
		
		var d = new Date(reg[1], reg[3]-1, reg[4]);
		if(d.getFullYear() == reg[1] && (d.getMonth() + 1) == reg[3] && d.getDate() == reg[4]){  
			var y = new Date().getFullYear();
		    return (y-reg[1]);
		}
	},
	
	getHeight: function() {
		/**
		* 该方法用于取得可视区域的高度
		* @author qzmoo.cn
		* @return 可视区域的高度
		*/	
		return document.documentElement.clientHeight;
	},
	
	getWidth: function() {
		/**
		* 该方法用于取得可视区域的宽
		* @author qzmoo.cn
		* @return 可视区域的宽
		*/	
		return document.documentElement.clientWidth;
	},
	
	getScrolPos: function() {
		/**
		* 该方法用于取得页面滚动高度
		* @author qzmoo.cn
		* @return 滚动区域的高度
		*/	
	    if(document.documentElement && document.documentElement.scrollTop){
	        return document.documentElement.scrollTop;
	    }else if(document.body){
	        return document.body.scrollTop;
	    }
	},
	
	getScrolltop: function(){
		window.onscroll = function(){
			return document.documentElement.scrollTop || document.body.scrollTop
		}
	},
	
	multi: function(a, b) {
		var m = 0, s1 = a.toString(), s2 = b.toString();
	    try {
	        m += s1.split(".")[1].length;
	    }
	    catch (e) {
	    }
	    try {
	        m += s2.split(".")[1].length;
	    }
	    catch (e) {
	    }
	    return Number(s1.replace(".", "")) * Number(s2.replace(".", "")) / Math.pow(10, m);
	},
	
	divi: function(a, b) {
		var t1 = 0, t2 = 0, r1, r2;
	    try {
	        t1 = a.toString().split(".")[1].length;
	    } catch (e) { }
	    try {
	        t2 = b.toString().split(".")[1].length;
	    } catch (e) { }
	    with (Math) {
	        r1 = Number(a.toString().replace(".", ""));
	        r2 = Number(b.toString().replace(".", ""));
	        return (r1 / r2) * pow(10, t2 - t1);
	    }
	},
	
	delarr: function(a) {
		var b = [].concat(a)
		for(var j=0, len=b.length; j<len; j++){
			if(b[j] == '' || typeof(b[j]) == 'undefined'){
				b.splice(j,1);
				len--
				j--
			}
		}
		return b
	},
	
	a: function(a) {
		return document.querySelectorAll(a);
	},
	
	q: function(s) {
		return document.querySelector(s); 
	},
	
	i: function(i) {
		return document.getElementById(i);
	},
	
	delTrim: function(a, b) {
		/**
		* 该方法用于去掉字符串的所有空格。
		* @author qzmoo.cn
		* @param a 需要去空格的字符串
		*/
		var reg = a.replace(/(^\s+)|(\s+$)/g,"");
		if(b.toLowerCase() == "g"){
		   reg = reg.replace(/\s/g,"");
		}
		return reg;
	},
	
	curTime: function() {
		/**
		* 该方法用于获取当前unix时间戳(秒)。
		* @author qzmoo.cn
		* @return <int>  unix时间戳(秒)  
		*/
		var oDate = new Date();
		var aDate = [];
		aDate.push(oDate.getFullYear());
		aDate.push(oDate.getMonth()+1);
		aDate.push(oDate.getDate());
		aDate.push(oDate.getHours());
		aDate.push(oDate.getMinutes());
		aDate.push(oDate.getSeconds());
		aDate.push(oDate.getDay());
		aDate.push(oDate.getTime());
		return aDate;
	},
	
	countdownTime: function(st) {
		/**              
		 * 倒计时
		 * @param <st> 2014-01-01 20:20:20  日期格式              
		 * @return <int>        unix时间戳(秒)              
		 */
		var t = (new Date(st)) - (new Date()); //计算剩余的毫秒数  
		
		if(t < 1){
			return '0天 - 00:00:00';
		}
		
        var d = parseInt(t / 1000 / 60 / 60 / 24, 10); //计算剩余的天数  
        var h = parseInt(t / 1000 / 60 / 60 % 24, 10); //计算剩余的小时数  
        var m = parseInt(t / 1000 / 60 % 60, 10); //计算剩余的分钟数  
        var s = parseInt(t / 1000 % 60, 10); //计算剩余的秒数  
        d = (d < 10) ? ('0' + d) : d;  
        h = (h < 10) ? ('0' + h) : h;
        m = (m < 10) ? ('0' + m) : m;
        s = (s < 10) ? ('0' + s) : s;
        
        return d + '天 - ' + h + ':' + m + ':' + s;
	},
	
	replaceall: function(a, b) {
		/**              
		 * 字符全部替换              
		 * @param <a> string    原始字符串              
		 * @param <b> string    需要替换的字符                          
		 */
		var reg = new RegExp(a, "gm");
		return this.replace(reg, b);   
	},
	
	getNetinfo: function() {
		var jsons = {};
		jsons.name = plus.os.name;
		jsons.version = plus.os.version;
		jsons.language = plus.os.language;
		jsons.vendor = plus.os.vendor;
		var types = {};
		types[plus.networkinfo.CONNECTION_UNKNOW] = "未知";
		types[plus.networkinfo.CONNECTION_NONE] = "未连接网络";
		types[plus.networkinfo.CONNECTION_ETHERNET] = "有线网络";
		types[plus.networkinfo.CONNECTION_WIFI] = "WiFi网络";
		types[plus.networkinfo.CONNECTION_CELL2G] = "2G蜂窝网络";
		types[plus.networkinfo.CONNECTION_CELL3G] = "3G蜂窝网络";
		types[plus.networkinfo.CONNECTION_CELL4G] = "4G蜂窝网络";
		jsons.network = types[plus.networkinfo.getCurrentType()];
		return jsons;
	},
	
	ajax: {
		post: function(b, c, d, g, f, h) {
			var h = h ? h : {};
			var f = f == 0 ? false : true;
			if (f) {
				qzmoo.loading()
			}
			var h = mui.ajax({
				type: 'POST',
				url: b,
				data: c,
				dataType: 'json',
				timeout: 60 * 1000,
				success: d,
				headers: h,
				complete: function() {
					setTimeout(function(){
						qzmoo.loaded()
					}, 100)
				},
				error: g
			})
			return h
		},
		get: function(b, c, d, g, f, h) {
			var h = h ? h : {};
			var f = f == 1 ? true : false;
			if (f) {
				qzmoo.loading()
			}
			var h = mui.ajax({
				type: 'get',
				url: b,
				data: c,
				dataType: 'json',
				timeout: 60 * 1000,
				success: d,
				headers: h,
				complete: function() {
					setTimeout(function(){
						qzmoo.loaded()
					}, 100)
				},
				error: g
			})
			return h
		}
	},
	
	updateSerivces: function () {
		plus.share.getServices( function(s){
			shares={};
			for(var i in s){
				var t=s[i];
				shares[t.id]=t;
			}
		}, function(e){} );
	},

	shareAction: function (id,ex,a){
		if(!id||!(s=shares[id])){
			return;
		}
		
		if ( s.authenticated ) {
			plus.nativeUI.closeWaiting();
			qzmoo.shareMessage(s,ex,a);
		} else {
			s.authorize( function(){
					plus.nativeUI.closeWaiting();
					qzmoo.shareMessage(s,ex,a);
				},function(e){
			});
		}
	},

	shareMessage: function (s,ex,a){
		var msg = {content:a.shareContent,extra:{scene:ex}};
		if(a.shareLink){
			msg.href = a.shareLink;
			if(a.shareTitle){
				msg.title = a.shareTitle;
			}
			if(a.shareContent){
				msg.content = a.shareContent;
			}
			if(a.shareImg){
				msg.pictures = msg.thumbs=[a.shareImg];
			}
		}else{
			if(a.shareImg){
				msg.pictures = msg.thumbs=[a.shareImg];
			}
		}
		
		s.send( msg, function(){
			qzmoo.loaded()
			qzmoo.toast('分享成功')
		}, function(e){
			qzmoo.loaded()
			qzmoo.toast('分享失败')
		} );
	},
	
	sortjson: function(array, field, reverse) {
		/**              
		 * json 数据排序              
		 * @param <array> array    原始json字符串              
		 * @param <field> string    排序字段             
		 * @param <reverse>  string   倒序              
		 */
		//数组长度小于2 或 没有指定排序字段 或 不是json格式数据
		if(array.length < 2 || !field || typeof array[0] !== "object") return array;
		//数字类型排序
		if(typeof array[0][field] === "number") {
			array.sort(function(x, y) { return x[field] - y[field]});
		}
		//字符串类型排序
		if(typeof array[0][field] === "string") {
			array.sort(function(x, y) { return x[field].localeCompare(y[field])});
		}
		//倒序
		if(reverse) {
			array.reverse();
		}
		return array;
	},
	
	toast: function(a, b, c) {
		if (b != 'long') {
			b = 'short'
		}
		var c = c ? c : 'bottom'
		plus.nativeUI.toast(a, {
			duration: b,
			verticalAlign: c
		})
	},
	
	alert: function(a) {
		plus.nativeUI.alert(a)
	},
	
	loading: function() {
		plus.nativeUI.showWaiting('', {
			padlock: true
		})
	},
	
	loaded: function() {
		plus.nativeUI.closeWaiting()
	},
	
	loadLazyImg: function(a) {
		em = document.querySelectorAll('.lazy[data-src]');
		a = a ? a : 6;
		len = em.length < a ? em.length : a;
		for (var i = 0; i < len; i++) {
			obj = em[i];
			src = obj.getAttribute('data-src');
			if (src) {
				qzmoo.getImg(src, obj);
				obj.removeAttribute('data-src')
			}
		}
		setTimeout(function() {
			if (em.length > a) {
				qzmoo.loadLazyImg()
			}
		}, 10)
	},
	
	getImg: function(b, c) {
		var d = b;
		var f = '_downloads/image/' + d + '.jpg';
		var g = plus.io.convertLocalFileSystemURL(f);
		c.src = 'http://www.qzmoo.com/1px.png';
		plus.io.resolveLocalFileSystemURL(f, function(a) {
			c.src = g
		}, function(e) {
			c.src = b;
			qzmoo.downImg(b)
		})
	},
	
	downImg: function(c) {
		var f = c;
		var g = '_downloads/image/' + f + '.jpg';
		var h = plus.io.convertLocalFileSystemURL(g);
		plus.io.resolveLocalFileSystemURL(g, function(a) {}, function(e) {
			task = plus.downloader.createDownload(c, {
				filename: g
			}, function(d, b) {
				if (b == 200) {} else {
					console.log("下载失败=" + h);
					task.abort();
					if (h) {
						plus.io.resolveLocalFileSystemURL(h, function(a) {
							a.remove()
						})
					}
				}
			});
			task.start()
		});
		return h
	},
	
	openKeyboard: function(g) {
		setTimeout(function() {
			if (mui.os.ios) {
				var a = plus.webview.currentWebview().nativeInstanceObject();
				a.plusCallMethod({
					"setKeyboardDisplayRequiresUserAction": false
				})
			} else {
				var b = plus.android.currentWebview();
				plus.android.importClass(b);
				b.requestFocus();
				var c = plus.android.importClass("android.content.Context");
				var d = plus.android.importClass("android.view.inputmethod.InputMethodManager");
				var e = plus.android.runtimeMainActivity();
				var f = e.getSystemService(c.INPUT_METHOD_SERVICE);
				f.toggleSoftInput(0, d.SHOW_FORCED)
			}
			document.querySelector(g).focus()
		}, 200)
	},
	
	closeKeyboard: function() {
		obj = document.querySelectorAll('input,select,textarea');
		for (var i = 0; i < obj.length; i++) {
			obj[i].blur()
		}
	},
	
	formatText: function(a) {
		var b = a.replace(new RegExp(/(\n)/g),'<br>').replace(new RegExp(/(\r\n)/g),'<br>').replace(new RegExp(/[ ]/g),'&nbsp;')
		return b
	},
	
	clearInput: function() {
		obj = document.querySelectorAll('input,textarea');
		for (var i = 0; i < obj.length; i++) {
			obj[i].value = ''
		}
	},
	
	slidein: function(a) {
		var obj = document.getElementById(a)
		obj.style.display = 'block';
		setTimeout(function(){
			obj.style.webkitTransform = 'translateX(0)';
			obj.style.transform = 'translateX(0)';
		},150);
	},
	
	slideout: function(a, b) {
		var obj = document.getElementById(a)
		obj.style.webkitTransform = 'translateX(100%)';
		obj.style.transform = 'translateX(100%)';
		setTimeout(function(){
			obj.style.display = 'none';
		},250)
	},
	
	downVeri: function(a, b, c) {
		var d = b;
		var obj = qzmoo.i(a);
		obj.style.backgroundColor = '#ccc';
		obj.innerHTML = '还剩' + b + '秒';
		b--;
		
		setTimeout(function(){
			if(b < 0){
				obj.style.backgroundColor = c;
				obj.innerHTML = '获取验证码';
				b = d;
				return;
			}else{
				qzmoo.downVeri(a, b, c);
			}
		},998)
	},
	
	goRate: function() {
		if (mui.os.ios) {
			location.href = 'https://itunes.apple.com/WebObjects/MZStore.woa/wa/viewContentsUserReviews?id=682211190&pageNumber=0&sortOrdering=2&type=&mt=8';
		} else if (mui.os.android) {
			plus.runtime.openURL("market://details?id=tk.qzmoo.H537675BD", function(e) {
				plus.runtime.openURL("market://details?id=tk.qzmoo.H537675BD", function(e) {
					mui.alert("360手机助手和应用宝，你一个都没装，暂时无法评分，感谢支持");
				}, "com.qihoo.appstore");
			}, "com.tencent.android.qqdownloader");
		}
	},
	
	setCid: function(uids, tyds) {
		var tyds = tyds, uids = uids
		qzmoo.ajax.post(localStorage.getItem('nbcip'), {
			service: 'gp100.100005',
			type: tyds,
			m_openid: uids,
			token: qzmoo.getPushInfo().split(',')[1],
			cid: qzmoo.getPushInfo().split(',')[0]
		}, function(d) {}, function(e){}, 0)
	},
	
	getNotice: function() {
		//ios  在应用内只会触发receive
		plus.push.addEventListener('receive', function(a){}, false)
		
		//ios 应用退出时触发click  点击后会触发receive事件
		plus.push.addEventListener('click', function(a){}, false)
	},
	
	getPushInfo: function() {
		var info = plus.push.getClientInfo();
		return info.clientid + ',' + info.token;
	},

}
